@@ -62,7 +62,7 @@ magconf_gconf_client_init (void)
     if (error != NULL)
     {
 	sru_warning (_("magconf:Failed to set notify:\n"));
-	sru_warning (_("Recomanded to delete ~/.gconf and ~/.gconfd directories"));
+	sru_warning (_("Recommended to delete ~/.gconf and ~/.gconfd directories"));
 	g_error_free(error);
 	error = NULL;
 	return FALSE;
