@@ -44,10 +44,17 @@
 #define DEFAULT_BRLMON_PORT			7000
 #define DEFAULT_REMOTE_PORT			7096
 /*____________________________< BRAILLE_DEFAULTS>___________________________*/
+#define MIN_SERIAL_PORT_NO			1
+#define MAX_SERIAL_PORT_NO			4
+
+#define MIN_TTY_CONSOL_NO			1
+#define MAX_TTY_CONSOL_NO			10
+
+
 #define DEFAULT_BRAILLE_ATTRIBUTES		8
-#define DEFAULT_BRAILLE_STYLE 			8
-#define DEFAULT_BRAILLE_CURSOR			2
-#define DEFAULT_BRAILLE_TRANSLATION 		"GE.A2B"
+#define DEFAULT_BRAILLE_STYLE 			"8"
+#define DEFAULT_BRAILLE_CURSOR_STYLE		"underline"
+#define DEFAULT_BRAILLE_TRANSLATION 		"GE"
 #define DEFAULT_BRAILLE_DEVICE 			"VARIO20"
 #define DEFAULT_BRAILLE_DEVICE_INDEX 		0
 #define DEFAULT_BRAILLE_DEVICE_COUNT		0
@@ -100,6 +107,7 @@
 #define DEFAULT_SPEECH_CURSORS			"NONE"
 #define DEFAULT_SPEECH_SPACES			"ALL"
 #define DEFAULT_SPEECH_ENGINE_VOICE		"V0 Adult Male 1 - IBM Viavoice GNOME Speech Driver"
+#define DEFAULT_SPEECH_ENGINE_DRIVER 		"IBM_Viavoice_GNOME_Speech_Driver"
 #define DEFAULT_SPEECH_DICTIONARY_ACTIVE	"NO"
 #define DEFAULT_SPEECH_DICTIONARY_ENTRY 	"USA<>United States Of America" 
 /*____________________________< /SPEECH_DEFAULTS>___________________________*/
@@ -179,9 +187,9 @@
 
 /*____________________________<BRAILLE>_______________________________________*/
 #define BRAILLE_ATTRIBUTES			"attribute"
-#define BRAILLE_STYLE 				"braille"
-#define BRAILLE_CURSOR				"cursor"
-#define BRAILLE_TRANSLATION 			"translation"
+#define BRAILLE_STYLE 				"braille_style"
+#define BRAILLE_CURSOR_STYLE			"cursor_style"
+#define BRAILLE_TRANSLATION 			"translation_table"
 #define BRAILLE_DEVICE 				"device"
 #define BRAILLE_PORT_NO 			"port_no"
 #define BRAILLE_FILL_CHAR 			"fill_char"
@@ -270,7 +278,7 @@
 #define SPEECH_MODIFIERS			"modifiers"
 #define SPEECH_CURSORS				"cursors"
 #define SPEECH_SPACES				"spaces"
-#define SPEECH_ENGINE_VOICE			"voice_parameters"
+#define SPEECH_ENGINE_DRIVERS			"engine_drivers" 
 #define SPEECH_VOICE_COUNT 			"voice_count"
 #define SPEECH_VOICE_TEST			"voice_test"
 #define SPEECH_GNOPERNICUS_SPEAKERS 		"gnopernicus_speakers"
@@ -318,14 +326,16 @@
 
 #define SPEECH_PATH  				"speech"
 #define SPEECH_SETTING_KEY_PATH  		"speech/settings/"
-#define SPEECH_VOICE_PARAM_KEY_PATH  		"speech/voice_parameters/"
+#define SPEECH_DRIVERS_PATH			"speech/drivers/"
+#define SPEECH_VOICE_PARAM_KEY_PATH  		"speech/voices_parameters/"
 #define SPEECH_VOICE_KEY_PATH			"speech/voice/"
 #define SPEECH_DICTIONARY_PATH			"speech/dictionary/"
 
-#define SPEECH_DICTIONARY_SECTION		"speech/dictionary"
-#define SPEECH_PARAMETER_SECTION 		"speech/voice_parameters"
 #define SPEECH_SETTING_SECTION   		"speech/setting"
+#define SPEECH_DRIVERS_SECTION			"speech/drivers"
+#define SPEECH_PARAMETER_SECTION 		"speech/voices_parameters"
 #define SPEECH_VOICE_SECTION     		"speech/voice"
+#define SPEECH_DICTIONARY_SECTION		"speech/dictionary"
 
 /*____________________________</SECTIONS>__________________________________*/
 /**
@@ -338,12 +348,12 @@ typedef enum {
 	CFGM_GNOPI,
 	CFGM_KBD_MOUSE,
 	CFGM_MAGNIFIER,
-	CFGM_SPEECH,
 	CFGM_SRCORE,
-	CFGM_SRLOW,
+	CFGM_SPEECH,
+	CFGM_SPEECH_VOICE_PARAM,
+	CFGM_SPEECH_VOICE,
 	CFGM_KEY_PAD,
-	CFGM_PRESENTATION,
-	CFGM_SPEECH_VOICES
+	CFGM_PRESENTATION
 } SRConfigurablesEnum;
 
 /**
